@@ -416,10 +416,15 @@ pub fn publish_package_request(
     release_tarball: Vec<u8>,
     api_key: &str,
     config: &Config,
+    replace: bool,
 ) -> http::Request<Vec<u8>> {
     // TODO: do all the package tarball construction
     config
-        .api_request(Method::POST, "publish", Some(api_key))
+        .api_request(
+            Method::POST,
+            format!("publish?replace={}", replace).as_str(),
+            Some(api_key),
+        )
         .header("content-type", "application/x-tar")
         .body(release_tarball)
         .expect("publish_package_request request")
@@ -429,11 +434,18 @@ pub fn publish_package_response(response: http::Response<Vec<u8>>) -> Result<(),
     // TODO: return data from body
     let (parts, body) = response.into_parts();
     match parts.status {
-        StatusCode::CREATED => Ok(()),
+        StatusCode::OK | StatusCode::CREATED => Ok(()),
         StatusCode::NOT_FOUND => Err(ApiError::NotFound),
         StatusCode::TOO_MANY_REQUESTS => Err(ApiError::RateLimited),
         StatusCode::UNAUTHORIZED => Err(ApiError::InvalidApiKey),
         StatusCode::FORBIDDEN => Err(ApiError::Forbidden),
+        StatusCode::UNPROCESSABLE_ENTITY => {
+            let body = &String::from_utf8_lossy(&body).to_string();
+            if body.contains("--replace") {
+                return Err(ApiError::NotReplacing);
+            }
+            return Err(ApiError::LateModification);
+        }
         status => Err(ApiError::unexpected_response(status, body)),
     }
 }
@@ -481,6 +493,12 @@ pub enum ApiError {
 
     #[error("this account is not authorized for this action")]
     Forbidden,
+
+    #[error("must explicitly express your intention to replace the release")]
+    NotReplacing,
+
+    #[error("can only modify a release up to one hour after publication")]
+    LateModification,
 }
 
 impl ApiError {
