@@ -884,7 +884,7 @@ async fn publish_package_success() {
     let key = "my-api-key-here";
     let tarball = std::include_bytes!("../test/example.tar.gz").to_vec();
 
-    let mock = mockito::mock("POST", "/publish")
+    let mock = mockito::mock("POST", "/publish?replace=false")
         .expect(1)
         .match_header("authorization", key)
         .match_header("accept", "application/json")
@@ -895,7 +895,7 @@ async fn publish_package_success() {
     config.api_base = http::Uri::from_str(&mockito::server_url()).unwrap();
 
     let result = crate::publish_package_response(
-        http_send(crate::publish_package_request(tarball, key, &config))
+        http_send(crate::publish_package_request(tarball, key, &config, false))
             .await
             .unwrap(),
     );
@@ -908,6 +908,80 @@ async fn publish_package_success() {
     mock.assert()
 }
 
+#[tokio::test]
+async fn modify_package_late() {
+    let key = "my-api-key-here";
+    let tarball = std::include_bytes!("../test/example.tar.gz").to_vec();
+
+    let mock = mockito::mock("POST", "/publish?replace=true")
+        .expect(1)
+        .match_header("authorization", key)
+        .match_header("accept", "application/json")
+        .with_status(422)
+        .with_body(
+            json!({
+                "errors": {"inserted_at": "can only modify a release up to one hour after publication"},
+                "message": "Validation error(s)",
+                "status": 422,
+            })
+            .to_string(),
+        )
+        .create();
+
+    let mut config = Config::new();
+    config.api_base = http::Uri::from_str(&mockito::server_url()).unwrap();
+
+    let result = crate::publish_package_response(
+        http_send(crate::publish_package_request(tarball, key, &config, true))
+            .await
+            .unwrap(),
+    );
+
+    match result {
+        Err(ApiError::LateModification) => (),
+        result => panic!("expected Err(ApiError::LateModification), got {:?}", result),
+    }
+
+    mock.assert()
+}
+
+#[tokio::test]
+async fn not_replacing() {
+    let key = "my-api-key-here";
+    let tarball = std::include_bytes!("../test/example.tar.gz").to_vec();
+
+    let mock = mockito::mock("POST", "/publish?replace=false")
+        .expect(1)
+        .match_header("authorization", key)
+        .match_header("accept", "application/json")
+        .with_status(422)
+        .with_body(
+            json!({
+                "errors": {"inserted_at": "must include the --replace flag to update an existing release"},
+                "message": "Validation error(s)",
+                "status": 422,
+            })
+            .to_string(),
+        )
+        .create();
+
+    let mut config = Config::new();
+    config.api_base = http::Uri::from_str(&mockito::server_url()).unwrap();
+
+    let result = crate::publish_package_response(
+        http_send(crate::publish_package_request(tarball, key, &config, false))
+            .await
+            .unwrap(),
+    );
+
+    match result {
+        Err(ApiError::NotReplacing) => (),
+        result => panic!("expected Err(ApiError::NotReplacing), got {:?}", result),
+    }
+
+    mock.assert()
+}
+
 #[tokio::test]
 async fn get_package_release_not_found() {
     let config = Config::new();
